import { visit, concatAST, Kind } from 'graphql';
import { StencilApolloVisitor } from './visitor';
import { extname } from 'path';
export var StencilComponentType;
(function (StencilComponentType) {
    StencilComponentType["functional"] = "functional";
    StencilComponentType["class"] = "class";
})(StencilComponentType || (StencilComponentType = {}));
export const plugin = (schema, documents, config) => {
    const allAst = concatAST(documents.reduce((prev, v) => {
        return [...prev, v.content];
    }, []));
    const operationsCount = allAst.definitions.filter(d => d.kind === Kind.OPERATION_DEFINITION);
    if (operationsCount.length === 0) {
        return '';
    }
    const allFragments = allAst.definitions.filter(d => d.kind === Kind.FRAGMENT_DEFINITION);
    const visitor = new StencilApolloVisitor(allFragments, config);
    const visitorResult = visit(allAst, { leave: visitor });
    return [
        visitor.getImports(),
        visitor.fragments,
        ...visitorResult.definitions.filter(t => typeof t === 'string')
    ].join('\n');
};
export const validate = async (schema, documents, config, outputFile) => {
    if (extname(outputFile) !== '.tsx') {
        throw new Error(`Plugin "stencil-apollo" requires extension to be ".tsx"!`);
    }
};
//# sourceMappingURL=index.js.map